@@ -18,7 +18,7 @@ our @EXPORT_OK = qw(new split split_array);
 
 our @EXPORT = qw(new split split_array);
 
-our $VERSION = '1.02';
+our $VERSION = '1.03';
 
 
 # Preloaded methods go here.
@@ -191,6 +191,8 @@ Languages currently supported by the module are:
 =over
 
 
+=item Catalan
+
 =item Dutch
 
 =item English
@@ -228,6 +230,11 @@ For example, "Article No. 24 states this." the No. is a nonbreaking prefix. Howe
 
 See the example prefix files included in the distribution for more examples.
 
+=head3 CREDITS
+
+Thanks for the following individuals for supplying nonbreaking prefix files:
+Bas Rozema (Dutch), HilE<aacute>rio Leal Fontes (Portuguese), JesE<uacute>s GimE<eacute>nez (Catalan & Spanish)
+
 =head2 EXPORT
 
 =over
@@ -272,8 +279,6 @@ Copyright (C) 2010 by Digital Silk Road
 
 Portions Copyright (C) 2005 by Philip Koehn and Josh Schroeder (used with permission)
 
-Portuguese nonbreaking prefix file copyright (C) 2009 by HilE<aacute>rio Leal Fontes (used with permission)
-
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
